create table account (
  _id integer primary key autoincrement,
  auth text,
  label text,
  selected integer,
  last_post integer,
  total_posts integer,
  unread_posts integer,
  last_updated integer,
  key_code text,
  starred_count integer,
  shared_count integer,
  source integer not null default 0,
  liked_count integer
);

create table cat(
  _id integer primary key autoincrement,
  cat_id text not null,
  label text not null,
  account_id integer not null references account(_id) on delete cascade,
  last_post integer,
  total_posts integer,
  unread_posts integer,
  updated integer not null default 0,
  sortid integer,
  starred_count integer,
  shared_count integer,
  liked_count integer,
  feed_count integer
);

create index if not exists IDX_CAT_ID on cat(cat_id);
create index if not exists IDX_CAT_ACCOUNT_ID on cat(account_id);

create table feed(
  _id integer primary key autoincrement,
  feed_id text not null,
  title text not null,
  account_id integer not null references account(_id) on delete cascade,
  last_post integer,
  total_posts integer,
  unread_posts integer,
  updated integer not null default 0,
  sortid integer,
  starred_count integer,
  shared_count integer,
  liked_count integer,
  broadcast integer,
  custom_settings int not null default 0,
  load_content text not null default 'NEVER',
  load_audio int not null default 0,
  load_video int not null default 0,
  load_images int not null default 0,
  view_open text not null default 'RSS',
  open_cached int not null default 1,
  base_link text,
  mobilizer text
);

create index if not exists IDX_FEED_ID on feed(feed_id);
create index if not exists IDX_FEED_ACCOUNT_ID on feed(account_id);

create table feed_cat(
  cat_id integer references cat(_id) on delete cascade,
  feed_id integer references feed(_id) on delete cascade,
  account_id integer not null references account(_id) on delete cascade,
  sortid integer,
  updated integer not null default 0,
  primary key(feed_id, cat_id)
);

create index if not exists IDX_FEED_CAT_ACCOUNT_ID on feed_cat(account_id);

create table post(
  _id integer primary key autoincrement,
  feed_id integer references feed(_id) on delete cascade,
  google_id text,
  title text,
  published integer,
  updated integer,
  link text,
  summary text,
  author text,
  crawl integer not null,
  status integer default 0,
  read_status_save integer default 0,
  server_status integer default 0,
  starred_status integer not null default 0,
  starred_status_save integer not null default 0,
  server_starred_status integer not null default 0,
  shared_status integer not null default 0,
  shared_status_save integer not null default 0,
  server_shared_status integer not null default 0,
  images_loaded integer not null default 0,
  liked_status integer not null default 0,
  liked_status_save integer not null default 0,
  server_liked_status integer not null default 0,
  via text,
  liking_users integer default 0,
  load_info text,
  continuation text,
  actual integer,
  enclosure_link text,
  enclosure_type integer default 0 not null,
  enclosure_type_s text,
  content_loaded integer not null default 0,
  enclosure_loaded integer not null default 0,
  image text
);

create index if not exists IDX_POST_ID on post(google_id);
create index if not exists IDX_POST_FEED_ID on post(feed_id);

create table exc(
  _id integer primary key autoincrement,
  stacktrace text not null
);

create table post_cat(
  cat_id integer references cat(_id) on delete cascade,
  post_id integer references post(_id) on delete cascade,
  account_id integer not null references account(_id) on delete cascade,
  primary key(post_id, cat_id)
);

create view root_feed_item as
  select
          0   _id,
          _id account_id,
          'all' str_id,
          'all' label,
          'cat' type,
          null base_link,
          last_post,
          unread_posts,
          total_posts,
          starred_count,
          shared_count,
          liked_count,
          1 feed_count,
          -1 sortid
  from account
  union all
  select  _id,
          account_id,
          cat_id str_id,
          label,
          'cat' type,
          null base_link,
          last_post,
          unread_posts,
          total_posts,
          starred_count,
          shared_count,
          liked_count,
          feed_count,
          sortid
  from cat
  union all
  select  _id,
          account_id,
          feed_id str_id,
          title label,
          'feed' type,
          base_link,
          last_post,
          unread_posts,
          total_posts,
          starred_count,
          shared_count,
          liked_count,
          0 feed_count,
          sortid
  from feed
  where (broadcast is null or broadcast = 0)
    and not exists(select 1 from feed_cat where feed_id = _id);

create view feed_item as
select f._id _id,
       f.account_id account_id,
       f.feed_id str_id,
       f.title label,
       'feed' type,
       f.last_post last_post,
       f.unread_posts unread_posts,
       f.total_posts total_posts,
       f.starred_count starred_count,
       f.shared_count shared_count,
       f.liked_count liked_count,
       f.base_link base_link,
       0 feed_count,
       f.sortid sortid,
       fc.cat_id cat_id
  from feed_cat fc
  left outer join feed f
    on fc.feed_id = f._id;

create view post_item as
select p._id _id,
      p.feed_id feed_id,
      p.google_id google_id,
      p.title title,
      p.published published,
      p.updated updated,
      p.link link,
      p.summary summary,
      p.author author,
      p.crawl crawl,
      p.status status,
      p.read_status_save read_status_save,
      p.server_status server_status,
      p.starred_status starred_status,
      p.starred_status_save starred_status_save,
      p.server_starred_status server_starred_status,
      p.shared_status shared_status,
      p.shared_status_save shared_status_save,
      p.server_shared_status server_shared_status,
      p.images_loaded images_loaded,
      p.liked_status liked_status,
      p.liked_status_save liked_status_save,
      p.server_liked_status server_liked_status,
      p.via via,
      p.liking_users liking_users,
      p.load_info load_info,
      p.continuation continuation,
      p.actual actual,
      p.enclosure_link enclosure_link,
      p.enclosure_type enclosure_type,
      p.enclosure_type_s enclosure_type_s,
      p.content_loaded content_loaded,
      p.enclosure_loaded enclosure_loaded,
      p.image image,
      f.title feed_title,
      f.open_cached open_cached,
      f.load_content load_content,
      f.load_audio load_audio,
      f.load_video load_video,
      f.view_open view_open,
      f.account_id account_id,
      f.custom_settings custom_settings
  from post p left outer join feed f on f._id = p.feed_id;
